@@ -48,37 +48,18 @@ GWEN_DIALOG *AB_EditAccountDialog_new(AB_PROVIDER *pro, AB_ACCOUNT *a, int doLoc
 {
   GWEN_DIALOG *dlg;
   AB_EDIT_ACCOUNT_DIALOG *xdlg;
-  GWEN_BUFFER *fbuf;
-  int rv;
 
-  dlg=GWEN_Dialog_new("ab_edit_account");
+  dlg=GWEN_Dialog_CreateAndLoadWithPath("ab_edit_account", AB_PM_LIBNAME, AB_PM_DATADIR,
+                                        "aqbanking/dialogs/dlg_editaccount.dlg");
+  if (dlg==NULL) {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "Could not create dialog \"ab_edit_account\".");
+    return NULL;
+  }
+
   GWEN_NEW_OBJECT(AB_EDIT_ACCOUNT_DIALOG, xdlg);
-  GWEN_INHERIT_SETDATA(GWEN_DIALOG, AB_EDIT_ACCOUNT_DIALOG, dlg, xdlg,
-                       AB_EditAccountDialog_FreeData);
+  GWEN_INHERIT_SETDATA(GWEN_DIALOG, AB_EDIT_ACCOUNT_DIALOG, dlg, xdlg, AB_EditAccountDialog_FreeData);
   GWEN_Dialog_SetSignalHandler(dlg, AB_EditAccountDialog_SignalHandler);
 
-  /* get path of dialog description file */
-  fbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=GWEN_PathManager_FindFile(AB_PM_LIBNAME, AB_PM_DATADIR,
-                               "aqbanking/dialogs/dlg_editaccount.dlg",
-                               fbuf);
-  if (rv<0) {
-    DBG_INFO(AQBANKING_LOGDOMAIN, "Dialog description file not found (%d).", rv);
-    GWEN_Buffer_free(fbuf);
-    GWEN_Dialog_free(dlg);
-    return NULL;
-  }
-
-  /* read dialog from dialog description file */
-  rv=GWEN_Dialog_ReadXmlFile(dlg, GWEN_Buffer_GetStart(fbuf));
-  if (rv<0) {
-    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d).", rv);
-    GWEN_Buffer_free(fbuf);
-    GWEN_Dialog_free(dlg);
-    return NULL;
-  }
-  GWEN_Buffer_free(fbuf);
-
   xdlg->provider=pro;
   xdlg->banking=AB_Provider_GetBanking(pro);
   xdlg->account=a;
@@ -720,6 +701,7 @@ int GWENHYWFAR_CB AB_EditAccountDialog_SignalHandler(GWEN_DIALOG *dlg,
   case GWEN_DialogEvent_TypeClose:
 
   case GWEN_DialogEvent_TypeLast:
+  default:
     return GWEN_DialogEvent_ResultNotHandled;
 
   }
